@@ -65,7 +65,8 @@ in both naming and ordering of parameters at every declaration.
 """
 
 
-def ordered_load(stream, Loader=yaml.Loader, object_pairs_hook=OrderedDict):
+def ordered_load(
+        stream, Loader=yaml.SafeLoader, object_pairs_hook=OrderedDict):
     """Load yaml as an ordered dict
 
     This allows us to inspect the order of the file on disk to make
@@ -222,9 +223,9 @@ class RestParametersDirective(Table):
             with open(fpath, 'r') as stream:
                 lookup = ordered_load(stream)
         except IOError:
-            self.env.warn(
-                self.env.docname,
-                "Parameters file %s not found" % fpath)
+            self.app.warn(
+                "Parameters file %s not found" % fpath,
+                (self.env.docname, None))
             return
         except yaml.YAMLError as exc:
             self.app.warn(exc)
@@ -233,9 +234,9 @@ class RestParametersDirective(Table):
         if lookup:
             self._check_yaml_sorting(fpath, lookup)
         else:
-            self.env.warn(
-                self.env.docname,
-                "Parameters file is empty %s" % fpath)
+            self.app.warn(
+                "Parameters file is empty %s" % fpath,
+                (self.env.docname, None))
             return
 
         YAML_CACHE[fpath] = lookup
@@ -299,35 +300,33 @@ class RestParametersDirective(Table):
             return
 
         content = "\n".join(self.content)
-        parsed = yaml.load(content)
+        parsed = yaml.safe_load(content)
         # self.app.info("Params loaded is %s" % parsed)
         # self.app.info("Lookup table looks like %s" % lookup)
         new_content = list()
         for paramlist in parsed:
             if not isinstance(paramlist, dict):
-                self.env.warn(
-                    "%s:%s" % (
-                        self.state_machine.node.source,
-                        self.state_machine.node.line),
+                self.app.warn(
                     ("Invalid parameter definition ``%s``. Expected "
                      "format: ``name: reference``. "
-                     " Skipping." % paramlist))
+                     " Skipping." % paramlist),
+                    (self.state_machine.node.source,
+                     self.state_machine.node.line))
                 continue
             for name, ref in paramlist.items():
                 if ref in lookup:
                     new_content.append((name, lookup[ref]))
                 else:
                     # TODO(sdague): this provides a kind of confusing
-                    # error message because env.warn isn't meant to be
+                    # error message because app.warn isn't meant to be
                     # used this way, however it does provide a way to
                     # track down where the parameters list is that is
                     # wrong. So it's good enough for now.
-                    self.env.warn(
-                        "%s:%s " % (
-                            self.state_machine.node.source,
-                            self.state_machine.node.line),
+                    self.app.warn(
                         ("No field definition for ``%s`` found in ``%s``. "
-                         " Skipping." % (ref, fpath)))
+                         " Skipping." % (ref, fpath)),
+                        (self.state_machine.node.source,
+                         self.state_machine.node.line))
 
                 # Check for path params in stanza
                 for i, param in enumerate(self.env.path_params):
@@ -341,13 +340,12 @@ class RestParametersDirective(Table):
             # Warn that path parameters are not set in rest_parameter
             # stanza and will not appear in the generated table.
             for param in self.env.path_params:
-                self.env.warn(
-                    "%s:%s " % (
-                        self.state_machine.node.source,
-                        self.state_machine.node.line),
+                self.app.warn(
                     ("No path parameter ``%s`` found in rest_parameter"
                      " stanza.\n"
-                     % param.rstrip('}').lstrip('{')))
+                     % param.rstrip('}').lstrip('{')),
+                    (self.state_machine.node.source,
+                     self.state_machine.node.line))
 
         # self.app.info("New content %s" % new_content)
         self.yaml = new_content
